# TIGR v2 backend

## Installation
### Requirements
* Ubuntu 18.04 or later (LTS version preferred) or any other Linux or BSD distro
(should work fine, but not tested)
* Superuser access level to OS
* Postgresql 10 or later
* Python 3.7 or later

### Install requirements
Install `Python 3.7`:
```console
$ sudo apt update
$ sudo apt upgrade
$ sudo apt install software-properties-common
$ sudo add-apt-repository ppa:deadsnakes/ppa
$ sudo apt install python3.7
```

Install Postgres DBMS:
```console
$ sudo apt install postgresql-10
```

Create python virtual environment. It is preferred that the venv folder should be outside project folder.
```console
$ sudo apt install python3.7-venv python3-pip
$ sudo pip3 install --upgrade pip
$ python3.7 -m venv <path_to_venv_folder>
```

Activate python venv
```console
$ source <path_to_venv_folder>/bin/activate
```

Install requirements
```console
(venv) $ cd <project_root_folder>
(venv) $ pip install -r requirements.txt
```

### Database configuration

Create database and user:
```console
$ sudo -u postgres psql
```

```postgresql
CREATE USER youruser WITH ENCRYPTED PASSWORD 'yourpass';
ALTER ROLE myprojectuser SET client_encoding TO 'utf8';
ALTER ROLE myprojectuser SET default_transaction_isolation TO 'read committed';
ALTER ROLE myprojectuser SET timezone TO 'UTC';

CREATE DATABASE yourdbname;
GRANT ALL PRIVILEGES ON DATABASE yourdbname TO youruser;
```

**For development only:**

In order for the user to be able to run unit tests:
```postgresql
ALTER USER youruser CREATEDB;
```

Exit `psql` tool with `\q`

### Server configuration
Create settings file
```console
(venv) $ cd <project_root_folder>/core/settings
(venv) $ cp example_<dev|prod>_settings.py settings.py
```

Open `settings.py` and edit relevant fields.
Things you should definitely change:
* SECRET_KEY
* ALLOWED_HOSTS
* DATABASES


### Start development server
```console
(venv) $ cd <path_to_project_root_folder>
(venv) $ python manage.py runserver
```

Development server will be available at `http://127.0.0.1:8000`

## Production deployment
Activate python venv
```console
$ source <path_to_venv_folder>/bin/activate
```
Install `gunicorn`:
```console
(venv) $ pip install gunicorn
```

Create static folder (should be in the location defined by STATIC_ROOT setting) and collect static
```console
(venv) $ mkdir -p <path_to_static>
(venv) $ python manage.py collectstatic
```
### Gunicorn

Create wsgi file
```console
(venv) $ cd <path_to_project_root_folder>/core
(venv) $ cp configs/example.wsgi.py wsgi.py
```

Edit wsgi.py and edit path to python venv, i.e.:
```python
# Relative path
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "../../")))
# OR absolute path
sys.path.insert(0, os.path.abspath("/abs/path/to/venv"))
```

Test gunicorn
```console
(venv) $ gunicorn --bind 0.0.0.0:8000 core.wsgi
```

Go to browser and test it (note that static files will not load - this is normal.
If gunicorn is working, then exit it with `Ctrl-C` and exit python venv with `deactivate` command.

Create gunicorn systemd file
```console
$ cd <path_to_project_root_folder>/core
$ cp configs/example.tigr-server.service tigr-server.service
```

Open file and edit the following parameters to reflect your environment:

`User` - the service will run from the specified user, the user should have read and write access to the project folder

`WorkingDirectory` - project root folder

`ExecStart=<path_to_venv_folder> --access-logfile - --workers <number_of_cpu - 1> --bind unix:<path_to_project_root_folder>/tigr-server.sock core.wsgi:application`


Start and enable service
```console
$ sudo ln -s <path_to_project_root>/core/tigr-server.service /etc/systemd/system/
$ sudo systemctl start tigr-server
$ sudo systemctl enable tigr-server
```

Check service
```console
$ sudo systemctl status tigr-server
```

Check socket file
```console
$ ls <path_to_project_root>
```
The output listing should include `tigr-server.sock` file.

### Nginx

Create nginx config file + static files + media files
```console
$ cd <path_to_project_root_folder>/core
$ cp configs/example.tigr-server.conf tigr-server.conf
```

Edit `tigr-server.conf` file to reflect your environment (see comments inside the file)

Link file and test config
```console
$ sudo ln -s <path_to_project_root>/core/tigr-server.conf /etc/nginx/sites-enabled/
$ sudo nginx -t
```

If config check executed successfully, restart nginx
```console
$ sudo systemctl resart nginx
```

Configure your DNS, then open browser, navigate to `http://your_server_fqdn` and make sure that everything works




