from rest_framework import serializers

from .models import Company, Department, CompanyCurrency
from core.serializers import ModelSerializer


class CompanyCurrencySerializer(ModelSerializer):
    class Meta:
        model = CompanyCurrency
        fields = (
            'id',
            'company',
            'currency',
            'main'
        )


class CompanySerializer(ModelSerializer):

    class Meta:
        model = Company
        fields = (
            'id',
            'name',
            'full_name',
            'legal_address',
            'postal_address',
            'parent_company',
            'currencies',
        )
        relation_fields = [('currencies', CompanyCurrencySerializer), ]


class DepartmentSerializer(ModelSerializer):
    subdepartments = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    employees = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)

    class Meta:
        model = Department
        fields = (
            'id',
            'name',
            'company',
            'parent_department',
            'subdepartments',
            'employees'
        )


class DepartmentUsersSerializer(DepartmentSerializer):
    class Meta:
        model = Department
        fields = DepartmentSerializer.Meta.fields

        from users.serializers import UserBaseSerializer
        relation_fields = [('employees', UserBaseSerializer)]

