from typing import Any

from django.db.models import QuerySet
from drf_yasg.utils import swagger_auto_schema
from rest_framework.decorators import action
from rest_framework.permissions import IsAuthenticatedOrReadOnly
from rest_framework.request import Request
from rest_framework.response import Response

from users.serializers import UserSerializer
from works.models import Work
from works.serializers import WorkSerializer
from .models import Company, Department
from roles.models import UserRole, Role
from .serializers import CompanySerializer, DepartmentSerializer
from core.viewsets import ModelViewSet

from django.conf import settings


class CompanyViewSet(ModelViewSet):
    queryset = Company.objects.all()
    serializer_class = CompanySerializer
    permission_classes = (IsAuthenticatedOrReadOnly, )

    def create(self, request: Request, *args: Any, **kwargs: Any) -> Response:
        response = super(CompanyViewSet, self).create(request, *args, **kwargs)
        r = Role.objects.get(id=settings.DEFAULT_ROLES['COMPANY_ADMIN'])
        c = Company.objects.get(id=response.data['id'])
        UserRole.objects.create(role=r, user=request.user, company=c)
        return response


class DepartmentViewSet(ModelViewSet):
    queryset = Department.objects.none()
    serializer_class = DepartmentSerializer
    filterset_fields = ('company', 'parent_department')

    def get_queryset(self) -> QuerySet:
        return Department.objects.filter(company=self.request.user.company)

    @swagger_auto_schema(
        operation_description='Get all users for departments',
        responses={200: UserSerializer(many=True)})
    @action(
        detail=True,
        serializer_class=UserSerializer,
    )
    def all_users(self, request, pk):
        department = self.get_object()
        return Response(UserSerializer(department.get_all_users(), many=True).data)

    @swagger_auto_schema(
        operation_description='Get all works for department',
        responses={200: WorkSerializer(many=True)}
    )
    @action(detail=True, methods=['GET'])
    def works(self, request, pk):
        department = self.get_object()
        return Response(
            WorkSerializer(
                Work.objects.filter(to_user__in=department.get_all_users()),
                many=True,
                include=['to_user', 'val_user', 'created_by', 'val_by', 'project'],
                context={'request': request}).data)
