from django.db import models
from core.helpers import get_file_path


class Partner(models.Model):
    company = models.ForeignKey('companies.Company', on_delete=models.CASCADE, verbose_name='Конпания')
    name = models.CharField(
        'наименование',
        max_length=255,
        unique=True,
        db_index=True,
    )
    full_name = models.TextField(
        'полное наименование',
        unique=True
    )
    postal_address = models.TextField('почтовый адрес', blank=True)
    legal_address = models.TextField('юридический адрес', blank=True)
    details = models.TextField('реквизиты', blank=True)
    locations = models.ManyToManyField(
        'core.Location',
        related_name='+',
        blank=True,
        verbose_name='местоположения'
    )

    def __str__(self):
        return self.name


# TODO partner person model (contact or smth)

class Contact(models.Model):
    organization = models.ForeignKey('Partner', on_delete=models.CASCADE,  related_name='contacts')
    first_name = models.CharField('Имя', max_length=255)
    middle_name = models.CharField('Отчество', max_length=255, blank=True)
    last_name = models.CharField('Фамилия', max_length=255, blank=True)
    position = models.CharField('Должность', max_length=255, blank=True)
    comment = models.CharField('Комментарий', max_length=255, blank=True)
    photo = models.ImageField(
        # _("Photo"),
        'фотография',
        upload_to=get_file_path,
        default='ava.png',
        null=True,
        blank=True
    )

    def __str__(self):
        return u'{} {} из {}'.format(self.last_name, self.first_name, self.organization)

    def get_full_name(self):
        result = '{}'.format(self.first_name)
        if self.middle_name:
            result = '{} {}'.format(result, self.middle_name)
        if self.last_name:
            result = '{} {}'.format(result, self.last_name)
        return result


class Telephone(models.Model):
    number = models.CharField('Номер телефона', max_length=50)
    primary = models.BooleanField('Основной', default=False)
    whatsapp = models.BooleanField('WhatsApp', default=False)
    telegram = models.BooleanField('Telegram', default=False)
    comment = models.CharField('Комментарий', max_length=255, blank=True)
    organization = models.ForeignKey('Partner', on_delete=models.CASCADE, related_name='telephones', blank=True, null=True)
    contact = models.ForeignKey('Contact', related_name='telephones', on_delete=models.CASCADE, blank=True, null=True)
    user = models.ForeignKey('users.User', related_name='telephones', on_delete=models.CASCADE, blank=True, null=True)

    def __str__(self):
        return self.number


class Email(models.Model):
    email = models.EmailField('Электронная почта')
    primary = models.BooleanField('Основная', default=False)
    comment = models.CharField('Комментарий', max_length=255, blank=True)
    organization = models.ForeignKey('Partner', on_delete=models.CASCADE, related_name='emails', blank=True, null=True)
    contact = models.ForeignKey('Contact', related_name='emails', on_delete=models.CASCADE, blank=True, null=True)

    def __str__(self):
        return self.email


class Vacation(models.Model):
    user = models.ForeignKey('users.User', on_delete=models.CASCADE, related_name='vacations', blank=True, null=True)
    start_date = models.DateField('начало отпуска')
    end_date = models.DateField('конец отпуска')
    paid = models.BooleanField('оплачиваемый отпуск', default=True)

    def __str__(self):
        return f'{self.user.full_name} отпуск {self.start_date}-{self.end_date} {"за свой счет" if self.paid else ""}'

    class Meta:
        ordering = ['user', 'start_date', ]