from rest_framework import serializers
from core.serializers import ModelSerializer
from companies.serializers import CompanySerializer
from .models import Partner, Contact, Telephone, Email, Vacation


class TelephoneSerializer(ModelSerializer):

    class Meta:
        model = Telephone
        fields = (
            'id',
            'number',
            'primary',
            'whatsapp',
            'telegram',
            'comment',
            'organization',
            'contact',
            'user'
        )


class EmailSerializer(ModelSerializer):

    class Meta:
        model = Email
        fields = (
            'id',
            'email',
            'primary',
            'comment',
            'organization',
            'contact'
        )


class ContactSerializer(ModelSerializer):
    telephones = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    emails = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)

    class Meta:
        model = Contact
        fields = (
            'id',
            'organization',
            'first_name',
            'middle_name',
            'last_name',
            'position',
            'comment',
            'photo',
            'telephones',
            'emails'
        )
        relation_fields = [
            ('telephones', TelephoneSerializer),
            ('emails', EmailSerializer),
        ]


class ContactPhotoSerializer(ModelSerializer):
    class Meta:
        model = Contact
        fields = ["photo"]

    def save(self, *args, **kwargs):
        if self.instance.photo:
            self.instance.photo = None
        return super().save(*args, **kwargs)


class PartnerSerializer(ModelSerializer):
    telephones = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    emails = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    contacts = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)

    class Meta:
        model = Partner
        fields = (
            'id',
            'name',
            'full_name',
            'details',
            'legal_address',
            'postal_address',
            'company',
            'contacts',
            'telephones',
            'emails'
        )
        relation_fields = [
            ('company', CompanySerializer),
            ('contacts', ContactSerializer),
            ('telephones', TelephoneSerializer),
            ('emails', EmailSerializer),
        ]


class VacationSerializer(ModelSerializer):

    class Meta:
        model = Vacation
        fields = (
            'id',
            'user',
            'start_date',
            'end_date',
            'paid'
        )