from core.viewsets import ModelViewSet
from .models import Partner, Contact, Telephone, Email, Vacation
from .serializers import PartnerSerializer, ContactSerializer, TelephoneSerializer, EmailSerializer, VacationSerializer, \
    ContactPhotoSerializer
from drf_yasg.utils import swagger_auto_schema
from rest_framework.decorators import action
from rest_framework.response import Response
from rest_framework import status
from rest_framework.parsers import MultiPartParser, FormParser
from rest_framework import viewsets
import os
from django.conf import settings


class PartnerViewSet(ModelViewSet):
    queryset = Partner.objects.all()
    serializer_class = PartnerSerializer
    filterset_fields = ('company', )


class ContactViewSet(ModelViewSet):
    queryset = Contact.objects.all()
    serializer_class = ContactSerializer
    filterset_fields = ('organization', )


class ContactPhotoViewSet(viewsets.GenericViewSet):
    queryset = Contact.objects.all()
    serializer_class = ContactPhotoSerializer
    filterset_fields = ('department', 'company')
    parser_classes = (FormParser, MultiPartParser)

    @swagger_auto_schema(operation_description='Upload user photo')
    @action(
        methods=['post'],
        detail=True,
        serializer_class=ContactPhotoSerializer,
    )
    def update_photo(self, request, pk):

        contact = Contact.objects.get(id=pk)

        serializer = ContactPhotoSerializer(data=request.data, instance=contact)
        if serializer.is_valid():
            path = str(settings.MEDIA_ROOT) + '/' + str(contact.photo) if contact.photo is not None else None
            serializer.save()
            if path is not None:
                if len(path.rsplit('/', 2)) > 2 and path.rsplit('/', 2)[2] != 'ava.png':
                    os.remove(path)
            return Response(serializer.data, status=status.HTTP_200_OK)
        else:
            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class TelephoneViewSet(ModelViewSet):
    queryset = Telephone.objects.all()
    serializer_class = TelephoneSerializer
    filterset_fields = ('organization', 'contact', 'user')


class EmailViewSet(ModelViewSet):
    queryset = Email.objects.all()
    serializer_class = EmailSerializer
    filterset_fields = ('organization', 'contact')


class VacationViewSet(ModelViewSet):
    queryset = Vacation.objects.all()
    serializer_class = VacationSerializer
    filterset_fields = ('user',)

