"""tigr2 URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import include, path, re_path

from rest_framework.routers import DefaultRouter

from rest_framework import permissions
from drf_yasg.views import get_schema_view
from drf_yasg import openapi
from django.conf.urls.static import static
from django.conf import settings

from projects import views as projectViews
from users import views as userViews
from roles import views as roleViews
from companies import views as companyViews
from contacts import views as contactViews
from news import views as newsentryViews
from questions import views as questionViews
from risks import views as riskViews
from stakeholders import views as stakeholderViews
from . import viewsets as coreViews
from contacts.urls import router as contact_router
from users.urls import router as user_router
from meetings import views as meeting_views
from works import views as works_views
from finance.urls import router as finance_router

from issues.urls import router as issues_router
from documents.urls import router as document_router

router = DefaultRouter()
router.register(r'projects', projectViews.ProjectsViewSet)
router.register(r'project-types', projectViews.ProjectTypesViewSet)
router.register(r'project-categories', projectViews.ProjectCategoriesViewSet)
router.register(r'project-groups', projectViews.ProjectGroupsViewSet)
router.register(r'project-meta', projectViews.ProjectMetaViewSet)
router.register(r'project-meta-value', projectViews.ProjectMetaValueViewSet)
router.register(r'project-stage', projectViews.ProjectStageViewSet)
router.register(r'project-view', projectViews.ProjectViewViewSet)
router.register('auth/users', userViews.MyDjoserUserViewSet)
router.register(r'user-last-project-view', userViews.UserLastProjectViewViewSet)
router.register(r'roles', roleViews.RoleViewSet)
router.register(r'user-roles', roleViews.UserRoleViewSet)
router.register(r'companies', companyViews.CompanyViewSet)
router.register(r'departments', companyViews.DepartmentViewSet, basename='')
router.register(r'organization', contactViews.PartnerViewSet)
router.register(r'telephone', contactViews.TelephoneViewSet)
router.register(r'vacations', contactViews.VacationViewSet)
router.register(r'email', contactViews.EmailViewSet)
router.register(r'news', newsentryViews.NewsEntryViewSet)
router.register(r'news-url', newsentryViews.NewsEntryUrlViewSet)
router.register(r'questions', questionViews.QuestionViewSet)
router.register(r'question-comments', questionViews.QuestionCommentViewSet)
router.register(r'risks', riskViews.RiskViewSet)
router.register(r'risks-categories', riskViews.RiskCategoryViewSet)
router.register(r'stakeholders', stakeholderViews.StakeholdersViewSet)
router.register(r'meetings', meeting_views.MeetingsViewSet)
router.register(r'works', works_views.WorksViewSet, basename='')
router.register(r'worklinks', works_views.WorkLinksViewSet)
router.register(r'history', coreViews.HistoryViewSet)

schema_view = get_schema_view(
   # TODO: write something reasonable below
   openapi.Info(
      title="TIGR API",
      default_version='v1',
      description="Test description",
      terms_of_service="https://www.google.com/policies/terms/",
      contact=openapi.Contact(email="contact@snippets.local"),
      license=openapi.License(name="BSD License"),
   ),
   public=True,
   permission_classes=[permissions.AllowAny,],
)

urlpatterns = [
    re_path(r'^swagger(?P<format>\.json|\.yaml)$', schema_view.without_ui(cache_timeout=0), name='schema-json'),
    path('swagger/', schema_view.with_ui('swagger', cache_timeout=0), name='schema-swagger-ui'),
    path('redoc/', schema_view.with_ui('redoc', cache_timeout=0), name='schema-redoc'),
    path('schema/', schema_view.as_view()),
    path('admin/', admin.site.urls),
    path('auth/', include('djoser.urls.authtoken')),
    path('', include(router.urls)),
    path('contacts/', include(contact_router.urls)),
    path('users/', include(user_router.urls)),
    path('issues/', include(issues_router.urls)),
    path('finance/', include(finance_router.urls)),
    path('documents/', include(document_router.urls)),
]

if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL,
                          document_root=settings.MEDIA_ROOT)
