# Generated by Django 3.0.2 on 2022-02-02 06:29

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import core.helpers
import mptt.fields


class Migration(migrations.Migration):

    replaces = [('documents', '0001_initial'), ('documents', '0002_auto_20220202_0926')]

    dependencies = [
        ('projects', '0009_projectview_current'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, default=None, editable=False, null=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('name', models.CharField(max_length=255, verbose_name='наименование')),
                ('description', models.TextField(blank=True, verbose_name='описание')),
                ('number', models.CharField(blank=True, max_length=255, verbose_name='номер документа')),
                ('date', models.DateField(blank=True, null=True, verbose_name='дата документа')),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='documents', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (('can_undelete', 'Can undelete this object'),),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DocumentMetaField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=50, verbose_name='имя метаданных')),
                ('meta_type', models.CharField(choices=[('DT', 'Дата'), ('CH', 'Короткий текст'), ('TXT', 'Длинный текст'), ('INT', 'Целое число'), ('FLT', 'Дробное число'), ('FK', 'Отношение'), ('MTM', 'Множественное отношение')], db_index=True, max_length=20, verbose_name='тип метаданных')),
                ('in_name', models.BooleanField(default=True, verbose_name='отображать в имени файла')),
                ('in_name_prefix', models.CharField(blank=True, max_length=10, verbose_name='префикс в для имени')),
                ('required', models.BooleanField(default=True, verbose_name='обязательное поле')),
                ('placeholder', models.CharField(blank=True, max_length=255, verbose_name='подсказка')),
                ('order', models.IntegerField(default=10, verbose_name='порядок')),
                ('model_name', models.CharField(max_length=50, verbose_name='имя модели')),
                ('model_app', models.CharField(max_length=50, verbose_name='имя приложения')),
            ],
            options={
                'ordering': ['order'],
            },
        ),
        migrations.CreateModel(
            name='DocumentType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='наименование')),
                ('order', models.PositiveSmallIntegerField(default=20, verbose_name='порядок')),
                ('lft', models.PositiveIntegerField(editable=False)),
                ('rght', models.PositiveIntegerField(editable=False)),
                ('tree_id', models.PositiveIntegerField(db_index=True, editable=False)),
                ('level', models.PositiveIntegerField(editable=False)),
                ('parent_type', mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='subtypes', to='documents.DocumentType', verbose_name='родительский тип')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DocumentMetaValue',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', models.TextField(verbose_name='значение')),
                ('object_id', models.BigIntegerField(verbose_name='идентификатор объекта')),
                ('document', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='metas', to='documents.Document')),
                ('meta', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='values', to='documents.DocumentMetaField')),
            ],
        ),
        migrations.AddField(
            model_name='document',
            name='document_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='documents.DocumentType', verbose_name='тип документа'),
        ),
        migrations.AddField(
            model_name='document',
            name='meta_fields',
            field=models.ManyToManyField(related_name='doc_types', to='documents.DocumentMetaField'),
        ),
        migrations.AddField(
            model_name='document',
            name='project_stages',
            field=models.ManyToManyField(related_name='documents', to='projects.ProjectStage'),
        ),
        migrations.AddField(
            model_name='document',
            name='projects',
            field=models.ManyToManyField(related_name='documents', to='projects.Project'),
        ),
        migrations.CreateModel(
            name='DocumentFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, default=None, editable=False, null=True)),
                ('version', models.PositiveSmallIntegerField(verbose_name='версия')),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('doc_file', models.FileField(upload_to=core.helpers.get_file_path)),
                ('MIME', models.CharField(blank=True, max_length=255, verbose_name='MIME')),
                ('extension', models.CharField(max_length=10, verbose_name='расширение')),
                ('comment', models.TextField(blank=True, verbose_name='описание файла')),
                ('original_name', models.TextField(blank=True, verbose_name='название при загрузке')),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='document_files', to=settings.AUTH_USER_MODEL)),
                ('document', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='files', to='documents.Document', verbose_name='файл')),
            ],
            options={
                'ordering': ('document', 'version'),
                'unique_together': {('version', 'document')},
            },
        ),
    ]
