from core.serializers import ModelSerializer
from documents.models import Document, DocumentFile, DocumentType, DocumentMetaValue, DocumentMetaField
from users.serializers import UserSerializer
from rest_framework import serializers
from rest_framework_recursive.fields import RecursiveField


class DocumentMetaValueSerializer(ModelSerializer):

    class Meta:
        model = DocumentMetaValue
        fields = '__all__'


class DocumentMetaFieldSerializer(ModelSerializer):

    class Meta:
        model = DocumentMetaField
        fields = (
            'id',
            'name',
            'meta_type',
            'in_name',
            'in_name_prefix',
            'required',
            'placeholder',
            'order',
            'model_name',
            'model_app',
            'values'
        )
        relation_fields = (
            ('values', DocumentMetaValueSerializer),
        )


class DocumentFileSerializer(ModelSerializer):

    class Meta:
        model = DocumentFile
        fields = (
            'id',
            'document',
            'version',
            'author',
            'created',
            'doc_file',
            'MIME',
            'extension',
            'comment',
            'original_name',
        )
        relation_fields = (
            ('author', UserSerializer),
        )


class DocumentTypeBaseSerializer(ModelSerializer):

    class Meta:
        model = DocumentType
        fields = (
            'id',
            'name',
            'order',
            # 'parent_type',
            'meta_fields',
        )
        relation_fields = (
            ('meta_fields', DocumentMetaFieldSerializer),
        )


class DocumentTypeSerializer(ModelSerializer):
    subtypes = serializers.ListSerializer(child=RecursiveField(), required=False, )

    class Meta:
        model = DocumentType
        fields = (
            'id',
            'name',
            'order',
            'parent_type',
            'subtypes',
            'meta_fields',
        )
        relation_fields = (
            ('meta_fields', DocumentMetaFieldSerializer),
            ('parent_type', DocumentTypeBaseSerializer)
        )


class DocumentUploadFileSerializer(ModelSerializer):
    class Meta:
        model = DocumentFile
        fields = ['doc_file'
                  ]

    def save(self, *args, **kwargs):
        if self.instance.doc_file:
            self.instance.doc_file = None
        return super().save(*args, **kwargs)


class DocumentSerializer(ModelSerializer):
    files = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    metas = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)

    class Meta:
        model = Document
        fields = (
            'id',
            'name',
            'description',
            'created',
            'author',
            'document_type',
            'number',
            'date',
            'projects',
            'project_stages',
            'files',
            'metas'
        )
        relation_fields = (
            ('document_type', DocumentTypeSerializer),
            ('files', DocumentFileSerializer),
            ('metas', DocumentMetaValueSerializer),
        )
