from core.viewsets import ModelViewSet
from .models import Document, DocumentMetaField, DocumentType, DocumentMetaValue, DocumentFile
from .serializers import DocumentSerializer, DocumentFileSerializer, \
    DocumentTypeSerializer, DocumentMetaValueSerializer, DocumentMetaFieldSerializer, DocumentUploadFileSerializer
from rest_framework import viewsets
from rest_framework.parsers import MultiPartParser, FormParser
from drf_yasg.utils import swagger_auto_schema
from rest_framework.decorators import action
from rest_framework.response import Response
from rest_framework import status
from django_filters import rest_framework as filters


class DocumentsViewSet(ModelViewSet):
    queryset = Document.objects.all()
    serializer_class = DocumentSerializer
    filterset_fields = ('projects', 'document_type')

    @swagger_auto_schema(operation_desqription='Gets last file for document')
    @action(
        detail=True,
        serializer_class=DocumentFileSerializer,
    )
    def get_last_file(self, request, pk):
        last_file = DocumentFile.objects.filter(document=pk).order_by('-created').values().distinct()[:1]
        if len(last_file):
            return Response(last_file[0])
        else:
            return Response(None)


class DocumentFileViewSet(ModelViewSet):
    queryset = DocumentFile.objects.all()
    serializer_class = DocumentFileSerializer


class DocumentFileUploadViewSet(viewsets.GenericViewSet):
    queryset = DocumentFile.objects.all()
    serializer_class = DocumentUploadFileSerializer
    filterset_fields = ('department', 'company')
    parser_classes = (FormParser, MultiPartParser)

    @swagger_auto_schema(operation_description='Upload file for document')
    @action(
        methods=['post'],
        detail=True,
        serializer_class=DocumentUploadFileSerializer,
    )
    def update_file(self, request, pk):

        file = DocumentFile.objects.get(id=pk)
        last_file = DocumentFile.objects.filter(document=pk).order_by('-created').values().distinct()[:1]

        serializer = DocumentUploadFileSerializer(data=request.data, instance=file)
        if serializer.is_valid():
            if len(last_file):
                file.version = last_file[0]['version'] + 1
            file.extension = request.data['doc_file'].name.split('.')[-1].lower()
            file.original_name = request.data['doc_file'].name.split('.')[0]
            file.MIME = request.data['doc_file'].content_type

            file.save()
            serializer.save()
            return Response(serializer.data, status=status.HTTP_200_OK)
        else:
            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class DocumentMetaFieldsViewSet(ModelViewSet):
    queryset = DocumentMetaField.objects.all()
    serializer_class = DocumentMetaFieldSerializer


class DocumentTypeFilter(filters.FilterSet):
    uncategorized = filters.BooleanFilter(field_name='parent_type', lookup_expr='isnull')


class DocumentTypeViewSet(ModelViewSet):
    queryset = DocumentType.objects.all()
    serializer_class = DocumentTypeSerializer
    # filterset_fields = ('parent_type',)
    filterset_class = DocumentTypeFilter


class DocumentMetaValueViewSet(ModelViewSet):
    queryset = DocumentMetaValue.objects.all()
    serializer_class = DocumentMetaValueSerializer
