from core.serializers import ModelSerializer
from .models import BudgetCategory, BudgetType, ProjectBudgetType, ProjectBudgetItem, ProjectBudget, ProjectExpense
from rest_framework import serializers
from djmoney.contrib.django_rest_framework import MoneyField


class BudgetCategorySerializer(ModelSerializer):
    class Meta:
        model = BudgetCategory
        fields = '__all__'


class BudgetTypeSerializer(ModelSerializer):
    class Meta:
        model = BudgetType
        fields = '__all__'
        relation_fields = [('category', BudgetCategorySerializer), ]


class BudgetStatsSerializer(serializers.Serializer):
    plan = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    plan_percent = serializers.DecimalField(max_digits=19, decimal_places=4, read_only=True)
    fact = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    fact_percent = serializers.DecimalField(max_digits=19, decimal_places=4, read_only=True)
    forecast = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    current_fact_and_fc = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    plan_fact_remaining = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    plan_fact_remaining_percent = serializers.DecimalField(max_digits=19, decimal_places=4, read_only=True)
    current_fact_and_fc_overplan = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    current_fact_and_fc_overplan_percent = serializers.DecimalField(max_digits=19, decimal_places=4, read_only=True)
    total_overplan = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    total_overplan_percent = serializers.DecimalField(max_digits=19, decimal_places=4, read_only=True)
    discipline = serializers.DecimalField(max_digits=19, decimal_places=4, read_only=True)


class ProjectBudgetTypeSerializer(ModelSerializer):
    name = serializers.ReadOnlyField()
    stats = BudgetStatsSerializer(read_only=True)

    class Meta:
        model = ProjectBudgetType
        fields = (
            'id',
            'budget_type',
            'code',
            'project',
            'name',
            'total_planned',
            'total_planned_currency',
            'stats',
        )
        relation_fields = [('budget_type', BudgetTypeSerializer)]


class ProjectExpenseSerializer(ModelSerializer):
    budget_type_name = serializers.ReadOnlyField()
    budget_type = serializers.IntegerField(read_only=True)
    editable = serializers.BooleanField(read_only=True)
    approved = serializers.BooleanField(read_only=True)
    period = serializers.DateField(read_only=True)

    class Meta:
        model = ProjectExpense
        fields = '__all__'


class ProjectBudgetItemSerializer(ModelSerializer):
    fact = MoneyField(max_digits=19, decimal_places=4, read_only=True)
    expenses = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)

    class Meta:
        model = ProjectBudgetItem
        fields = (
            'id',
            'date',
            'project',
            'budget_type',
            'plan',
            'plan_currency',
            'forecast',
            'forecast_currency',
            'fact',
            'approved',
            'approved_by',
            'approved_at',
            'expenses',
        )
        relation_fields = [('expenses', ProjectExpenseSerializer), ]


class ProjectBudgetSerializer(ModelSerializer):
    stats = BudgetStatsSerializer(read_only=True)

    class Meta:
        model = ProjectBudget
        fields = (
            'id',
            'project',
            'code',
            'period_start',
            'period_end',
            'total_planned',
            'total_planned_currency',
            'approved',
            'approved_by',
            'approved_at',
            'stats',
        )






