from core.serializers import ModelSerializer
from issues.models import IssueDomain, IssueCategory, Issue
from users.serializers import UserSerializer
from rest_framework import serializers


class IssueDomainSerializer(ModelSerializer):
    class Meta:
        model = IssueDomain
        fields = (
            'id',
            'name',
            'order',
            'company'
        )


class IssueCategorySerializer(ModelSerializer):
    class Meta:
        model = IssueCategory
        fields = (
            'id',
            'name',
            'order',
            'company'
        )


class IssueSerializer(ModelSerializer):
    is_problem = serializers.BooleanField(read_only=True)
    risk_assessment = serializers.IntegerField(read_only=True)

    class Meta:
        model = Issue
        fields = (
            'id',
            'company',
            'project',
            'category',
            'name',
            'description',
            'probability',
            'severity',
            'author',
            'control_method',
            'consequences',
            'response',
            'damage',
            'damage_currency',
            'responsible_user',
            'domains',
            'order',
            'cause',
            'root_cause',
            'is_problem',
            'risk_assessment'
        )
        relation_fields = [
            ('author', UserSerializer),
            ('category', IssueCategorySerializer),
            ('responsible_user', UserSerializer),
            ('domains', IssueDomainSerializer),
        ]
