from django.db.models import QuerySet

from core.viewsets import ModelViewSet
from issues.models import Issue, IssueDomain, IssueCategory
from issues.serializers import IssueSerializer, IssueCategorySerializer, IssueDomainSerializer


class IssueViewSet(ModelViewSet):
    serializer_class = IssueSerializer
    filterset_fields = ('project', )

    def get_queryset(self) -> QuerySet:
        return Issue.objects.filter(company=self.request.user.company)


class IssueDomainViewSet(ModelViewSet):
    serializer_class = IssueDomainSerializer
    filterset_fields = ('company', )

    def get_queryset(self) -> QuerySet:
        return IssueDomain.objects.filter(company=self.request.user.company)


class IssueCategoryViewSet(ModelViewSet):
    serializer_class = IssueCategorySerializer
    filterset_fields = ('company', )

    def get_queryset(self) -> QuerySet:
        return IssueCategory.objects.filter(company=self.request.user.company)
