from core.viewsets import ModelViewSet
from .models import Meeting
from .serializers import MeetingSerializer
from django.core.mail import send_mail
from django.core.mail import EmailMessage
from datetime import datetime
from core.settings import settings
from django.utils import timezone
from django.core.mail import send_mass_mail
from rest_framework.response import Response

class MeetingsViewSet(ModelViewSet):
    queryset = Meeting.objects.all()
    serializer_class = MeetingSerializer
    filterset_fields = ('project',)

    def create(self, request, *args, **kwargs):
        response = super(MeetingsViewSet, self).create(request, *args, **kwargs)
        meeting = Meeting.objects.get(pk=response.data['id'])
        meeting_date = timezone.localtime(meeting.start)
        message_title = 'Новое совещание {date}'.format(date=meeting_date.strftime('%d.%m.%Y %H:%M'))
        meeting_required_members = list(meeting.required_members.all())
        message_list = []
        for member in meeting_required_members + list(meeting.eligible_members.all()):
            message = 'Уважаемый {name}!' \
                      ' \nПриглашаем вас на совещание на тему "{topic}", место проведения: {place}, {required} ' \
                      ' \nПовестка совещания: {agenda}' \
                      ' \nДата и время совещания: {date},' \
                      ' \nОрганизатор совещания: {author}'.format(name=member.first_name + ' ' + member.middle_name,
                                                                  topic=meeting.topic,
                                                                  agenda=meeting.agenda,
                                                                  date=meeting_date.strftime('%d.%m.%Y %H:%M'),
                                                                  author=meeting.author.full_name,
                                                                  place=meeting.location,
                                                                  required='как обязательный гость' if member in meeting_required_members else 'ваше присутствие по-желанию')
            message_list.append((message_title,
                                 message,
                                 settings.SERVER_EMAIL,
                                 [member.email]))  # sending mail
        send_mass_mail(message_list)
        print('aaaaaa')
        return response

    def destroy(self, request, *args, **kwargs):
        meeting = self.get_object()
        meeting_title = meeting.topic
        meeting_date = timezone.localtime(meeting.start)
        message_title = 'Совещание "{title}" было отменено'.format(title=meeting_title)
        message = 'Совещание на тему "{title}" от {date} было отменено. ' \
                  '\nДля подробностей можете обратиться к организатору- {author} ({mail})'.format(title=meeting_title,
                                                                                         date=meeting_date.strftime('%d.%m.%Y %H:%M'),
                                                                                         author=meeting.author.short_name,
                                                                                         mail=meeting.author.email)
        list_mail = [member.email for member in list(meeting.required_members.all()) + list(meeting.eligible_members.all())]
        send_mail(message_title,
                  message,
                  settings.SERVER_EMAIL,
                  list_mail)
        meeting.delete()
        return Response({'status': 'deleted'})

    def update(self, request, *args, **kwargs):
        meeting_without_changes = self.get_object()
        meeting_rm_without_changes = list(meeting_without_changes.required_members.all()) #Обязательняе участники до изменений
        meeting_em_without_changes = list(meeting_without_changes.eligible_members.all()) #Участники по желанию до изменений
        response = super(MeetingsViewSet, self).update(request, *args, **kwargs)
        meeting_with_changes = Meeting.objects.get(pk=response.data['id'])
        meeting_rm_with_changes = list(meeting_with_changes.required_members.all()) #Обязательняе участники после изменений
        meeting_em_with_changes = list(meeting_with_changes.eligible_members.all()) #Участники по желанию после изменений
        # message_title = 'Совещание "{title}" было изменено'.format(title=meeting_without_changes.topic)
        meeting_date = timezone.localtime(meeting_with_changes.start)
        message_list = []
        # Нужно ли здесь писать разные сообщения если изменена только дата или повестка?
        # meeting_changed_date = 'Начало совещания было перенесено на {date}'.format(date=meeting_with_changes.start)
        # meeting_changed_location = 'Место совещания было перенесено {location}'.format(location=meeting_with_changes.location)
        # meeting_changed_agenda = 'Повестка совещания была изменена {agenda}'.format(agenda=meeting_with_changes.agenda)
        # все запихнуть в сообщение
        # добавить проверку на новых пользователей, и если пользователь новый, то ему отправить другое сообщение
        # print('без изменений', meeting_rm_without_changes, 'ииииии', meeting_rm_with_changes)
        # print('тема без изменений', meeting_without_changes.topic, 'тема с изменениями', meeting_with_changes.topic)
        # Проверка измений в обязательных пользователях и рассылка сообщений для них
        if (meeting_rm_without_changes != meeting_rm_with_changes):
            print('изменены обязательные участники')
            deleted_rm_users = list(set(meeting_rm_without_changes) - set(meeting_rm_with_changes))
            added_rm_users = list(set(meeting_rm_with_changes) - set(meeting_rm_without_changes))
            unchanged_users = list(set(meeting_rm_without_changes) & set(meeting_rm_with_changes))
            print('added: ', added_rm_users, 'deleted: ', deleted_rm_users, 'unchanged: ', unchanged_users )
            for member in added_rm_users + deleted_rm_users + unchanged_users:
                message_title = '{title_message}'.format(title_message = 'Новое совещание' if member in added_rm_users else 'Вы исключены из списка обязетльных участников')
                message = 'Уважаемый {name}! \nВы были {required}'.format( name = member.first_name + ' ' + member.middle_name,
                                                                          required = 'приглашены на совещание, как обязательный участник' if member in added_rm_users else 'исключены из списка обязательных участников!')
                message_list.append((message_title,
                                     message,
                                     settings.SERVER_EMAIL,
                                     [member.email]))
        # Проверка измений в пользователях по-желанию и рассылка сообщений для них
        elif(meeting_em_without_changes != meeting_em_with_changes):
            print('изменены участники по желанию')
            deleted_em_users = list(set(meeting_em_without_changes) - set(meeting_em_with_changes))
            added_em_users = list(set(meeting_em_with_changes) - set(meeting_em_without_changes))
            # Здесь еще сделать список неизмененных пользователей и делать сообщение еще и для них
            print('added: ', added_em_users, 'deleted: ', deleted_em_users)
            for member in added_em_users + deleted_em_users:
                message_title = '{title_message}'.format(title_message='Новое совещание' if member in added_em_users  else 'Вы исключены из списка участников по-желанию')
                message = 'Уважаемый {name}! \nВы были {required}'.format(name=member.first_name + ' ' + member.middle_name,
                                                                          required='приглашены на совещание, посещение по-желанию' if member in added_em_users else 'исключены из списка участников по-желанию!')
                message_list.append((message_title,
                                     message,
                                     settings.SERVER_EMAIL,
                                     [member.email]))
        else:
            print('участники не менялись, изменилась другая инфа')
            list_mail = [member.email for member in meeting_rm_with_changes + meeting_em_with_changes]
            message_title = 'Совещание "{title}" было изменено'.format(title=meeting_without_changes.topic)
            message = 'В общем, что-то изменилось в совещании'
            message_list.append((message_title,
                                     message,
                                     settings.SERVER_EMAIL,
                                     list_mail))
        # if (meeting_without_changes.topic == meeting_with_changes.topic):
        #     message = 'Совещание на тему "{title}" было изменено. ' \
        #               '\nДата и время совещания: {date}, ' \
        #               '\nМесто проведения: {place} ' \
        #               '\nПовестка совещания: {agenda}' \
        #               '\nДля подробностей можете обратиться к организатору: {author} ({mail})'.format(title=meeting_with_changes.topic,
        #                                                                                               date=meeting_date.strftime('%d.%m.%Y %H:%M'),
        #                                                                                               place=meeting_with_changes.location,
        #                                                                                               agenda=meeting_with_changes.agenda,
        #                                                                                               author=meeting_with_changes.author.short_name,
        #                                                                                               mail=meeting_with_changes.author.email)
        # else:
        #     message = 'Была изменена тема совещания "{title_with_changes}". ' \
        #               '\nДата и время совещания: {date}, ' \
        #               '\nМесто проведения: {place} ' \
        #               '\nПовестка совещания: {agenda}' \
        #               '\nДля подробностей можете обратиться к организатору: {author} ({mail})'.format(title_with_changes=meeting_with_changes.topic,
        #                                                                                               title_without_changes=meeting_without_changes.topic,
        #                                                                                               date=meeting_date.strftime('%d.%m.%Y %H:%M'),
        #                                                                                               place=meeting_with_changes.location,
        #                                                                                               agenda=meeting_with_changes.agenda,
        #                                                                                               author=meeting_with_changes.author.short_name,
        #                                                                                               mail=meeting_with_changes.author.email)
        send_mass_mail(message_list)
        return response

