from django.db import models
from django.utils import timezone


class NewsEntry(models.Model):
    date = models.DateTimeField(
        'дата публикации',
        default=timezone.now,
    )
    user = models.ForeignKey(
        'users.User',
        verbose_name='Кто опубликовал',
        on_delete=models.CASCADE,
        related_name='news',
    )
    project = models.ForeignKey(
        'projects.Project',
        verbose_name='проект',
        on_delete=models.CASCADE,
        related_name='news',
        blank=True,
        null=True,
    )
    company = models.ForeignKey(
        'companies.Company',
        verbose_name='компания',
        on_delete=models.CASCADE,
        related_name='company',
        blank=True,
        null=True,
    )
    departament = models.ForeignKey(
        'companies.Department',
        verbose_name='департамент',
        on_delete=models.CASCADE,
        related_name='department',
        blank=True,
        null=True,
    )
    title = models.CharField(
        'Заголовок новости',
        max_length=255,
    )
    text = models.TextField(
        'Текст новости',
    )
    watchers = models.ManyToManyField(
        'users.User',
        related_name='newsEntry_watched',
        blank=True)

    class Meta:
        ordering = ['-date']

    def news_name(self):
        """
            Returns name project or company or department, if exist and title news
            i.e.: Проект №1 - Открытие проекта

            :return:  name project, company or department - title news
            :rtype: str
        """
        project = self.project
        company = self.company
        departament = self.departament
        if project is None:
            project = ' '
        if company is None:
            company = ' '
        if departament is None:
            departament = ' '
        return str(project) + str(company) + str(departament) + ' - ' + str(self.title)

    def __str__(self):
        return self.news_name()


class NewsEntryUrl(models.Model):
    entry = models.ForeignKey(
        NewsEntry,
        on_delete=models.CASCADE,
        related_name='urls'
    )
    link = models.URLField(
        'Ссылка',
        max_length=1000,
    )
    link_description = models.CharField(
        'Описание ссылки',
        max_length=255,
    )
