from django.utils import timezone
from django.utils.translation import gettext_lazy as _

from django.db import models


class Notification(models.Model):
    class SeverityChoices(models.TextChoices):
        DEBUG = 'DEBUG', _('Debug')
        INFO = 'INFO', _('Info')
        WARNING = 'WARNING', _('Warning')
        ERROR = 'ERROR', _('Error')

    name_template = models.CharField('шаблон наименования', max_length=255)
    name_params = models.JSONField(verbose_name='параметры наименования', null=True, blank=True)
    description_template = models.CharField('шаблон описания', max_length=255, null=True, blank=True)
    description_params = models.JSONField(verbose_name='параметры описания', null=True, blank=True)
    created_at = models.DateTimeField('создано в', default=timezone.now)
    created_by = models.ForeignKey('users.User', verbose_name='автор', null=True, blank=True,
                                   on_delete=models.PROTECT, related_name='notification_author')
    severity = models.CharField('важность', max_length=7, choices=SeverityChoices.choices, default=SeverityChoices.INFO)
    url = models.URLField('ссылка', blank=True, null=True)
    recipient = models.ForeignKey('users.User', related_name='notifications', on_delete=models.CASCADE)

