# Generated by Django 2.1 on 2019-02-25 22:11

from django.db import migrations, models
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('companies', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=30, unique=True, verbose_name='название проекта')),
                ('eng_name', models.CharField(max_length=20, unique=True, verbose_name='английское название (для ссылок)')),
                ('description', models.TextField(blank=True, verbose_name='описание')),
                ('start_date', models.DateField(blank=True, null=True, verbose_name='начало работы')),
                ('end_date', models.DateField(blank=True, null=True, verbose_name='конец работы')),
                ('budget', models.FloatField(blank=True, null=True, verbose_name='бюджет работы')),
                ('abbr', models.CharField(max_length=10, unique=True, verbose_name='аббревиатура')),
                ('status', models.CharField(choices=[('FUT', 'Перспективный'), ('ACT', 'Открытый'), ('ARCH', 'Архивный')], db_index=True, default='FUT', max_length=20, verbose_name='статус проекта')),
                ('has_problems', models.BooleanField(default=False, verbose_name='проблемный')),
                ('customer', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='projects_customer', to='companies.Company', verbose_name='заказчик')),
                ('general_customer', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='projects_general_customer', to='companies.Company', verbose_name='генеральный заказчик')),
            ],
        ),
        migrations.CreateModel(
            name='ProjectCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='имя категории')),
                ('eng_name', models.CharField(max_length=100, null=True, unique=True, verbose_name='name')),
                ('order', models.IntegerField(default=10, verbose_name='порядок')),
                ('about', models.TextField(blank=True, verbose_name='описание категории')),
            ],
            options={
                'verbose_name_plural': 'Project categories',
                'ordering': ['order'],
            },
        ),
        migrations.CreateModel(
            name='ProjectGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='наименование')),
                ('lft', models.PositiveIntegerField(db_index=True, editable=False)),
                ('rght', models.PositiveIntegerField(db_index=True, editable=False)),
                ('tree_id', models.PositiveIntegerField(db_index=True, editable=False)),
                ('level', models.PositiveIntegerField(db_index=True, editable=False)),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='project_groups', to='companies.Company', verbose_name='компания')),
                ('parent_group', mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='subgroups', to='projects.ProjectGroup', verbose_name='родительский портфель')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProjectPreferences',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('finance', models.BooleanField(default=True, verbose_name='финансы')),
                ('procurements', models.BooleanField(default=True, verbose_name='закупки')),
                ('contractors', models.BooleanField(default=True, verbose_name='контрагенты')),
                ('assignments', models.BooleanField(default=True, verbose_name='поручения')),
                ('products', models.BooleanField(default=True, verbose_name='продукты')),
                ('reports', models.BooleanField(default=True, verbose_name='отчеты')),
                ('questions', models.BooleanField(default=True, verbose_name='вопросы')),
                ('works', models.BooleanField(default=True, verbose_name='работы')),
                ('project', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='preferences', to='projects.Project', verbose_name='проект')),
            ],
        ),
        migrations.CreateModel(
            name='ProjectStage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('stage', models.SmallIntegerField(verbose_name='этап')),
                ('name', models.TextField(blank=True, verbose_name='полное наименование этапа')),
                ('start_date', models.DateField(verbose_name='начало этапа')),
                ('end_date', models.DateField(verbose_name='конец этапа')),
                ('budget', models.FloatField(blank=True, null=True, verbose_name='бюджет этапа')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='projects.Project')),
            ],
        ),
        migrations.CreateModel(
            name='ProjectType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=30, verbose_name='имя типа')),
                ('about', models.TextField(blank=True, verbose_name='описание типа')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='types', to='projects.ProjectCategory', verbose_name='категория')),
            ],
            options={
                'ordering': ['category', 'name'],
            },
        ),
        migrations.AddField(
            model_name='project',
            name='project_group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='projects', to='projects.ProjectGroup', verbose_name='группа проектов'),
        ),
        migrations.AddField(
            model_name='project',
            name='project_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='projects', to='projects.ProjectType', verbose_name='тип проекта'),
        ),
    ]
