from .models import Project, ProjectType, ProjectGroup, ProjectMeta, ProjectMetaValue, ProjectView, ProjectStage
from .serializers import ProjectSerializer, \
    ProjectTypeSerializer, \
    ProjectGroupSerializer, \
    ProjectMetaSerializer, ProjectMetaValueSerializer, ProjectViewSerializer, \
    ProjectStageSerializer, ProjectCategory, ProjectCategorySerializer
from core.viewsets import ModelViewSet
from drf_yasg.utils import swagger_auto_schema
from rest_framework.decorators import action
from rest_framework.response import Response


class ProjectsViewSet(ModelViewSet):
    queryset = Project.objects.all()
    serializer_class = ProjectSerializer
    filterset_fields = ('project_group', 'project_type')


class ProjectTypesViewSet(ModelViewSet):
    queryset = ProjectType.objects.all()
    serializer_class = ProjectTypeSerializer


class ProjectCategoriesViewSet(ModelViewSet):
    queryset = ProjectCategory.objects.all()
    serializer_class = ProjectCategorySerializer


class ProjectGroupsViewSet(ModelViewSet):
    queryset = ProjectGroup.objects.all()
    serializer_class = ProjectGroupSerializer
    filterset_fields = ('company', 'parent_group')


class ProjectStageViewSet(ModelViewSet):
    queryset = ProjectStage.objects.all()
    serializer_class = ProjectStageSerializer
    filterset_fields = ('project',)


class ProjectMetaViewSet(ModelViewSet):
    queryset = ProjectMeta.objects.all()
    serializer_class = ProjectMetaSerializer
    filterset_fields = ('owner', 'public')

    @swagger_auto_schema(operation_description='Gets project meta data types')
    @action(
        detail=False,
    )
    def get_data_types(self, request):
        data_type_list = []
        data_types = ProjectMeta.DATA_TYPE_CHOICES
        for type in data_types:
            data_type_list.append({type[0]: type[1]})
        return Response(data_type_list)


class ProjectMetaValueViewSet(ModelViewSet):
    queryset = ProjectMetaValue.objects.all()
    serializer_class = ProjectMetaValueSerializer
    filterset_fields = ('meta', 'project')


class ProjectViewViewSet(ModelViewSet):
    queryset = ProjectView.objects.all()
    serializer_class = ProjectViewSerializer
    filterset_fields = ('owner', 'public')

