from django.db import models
from django.utils import timezone
from mptt.models import MPTTModel, TreeForeignKey

class Question(models.Model):
    user = models.ForeignKey (
        'users.User',
        verbose_name='Кто опубликовал',
        on_delete=models.SET_NULL,
        related_name='questions',
        null = True,
    )
    text = models.TextField(
        'Текст вопроса',
    )
    project = models.ForeignKey(
        'projects.Project',
        verbose_name='проект',
        on_delete=models.CASCADE,
        related_name='questions',
    )
    date = models.DateTimeField(
        'дата публикации',
        default=timezone.now,
    )

    class Meta:
        ordering = ['-date']

    def __str__(self):
        return str(self.project) + ' - ' + str(self.text)

class QuestionComment(models.Model):
    user = models.ForeignKey(
        'users.User',
        verbose_name='Кто опубликовал',
        on_delete=models.SET_NULL,
        related_name='comments',
        null=True,
    )
    comment = models.TextField(
        'Комментарий',
    )
    date = models.DateTimeField(
        'дата публикации',
        default=timezone.now,
    )
    question = models.ForeignKey(
        'questions.Question',
        on_delete=models.CASCADE,
        related_name='comments',
        verbose_name='Вопрос',
        blank=True,
        null=True
    )
    parent_comment = models.ForeignKey(
        'self',
        on_delete=models.CASCADE,
        verbose_name='Комментарий',
        related_name='children',
        blank=True,
        null=True
    )
    answer = models.BooleanField(
        'является ответом',
        default=False,
    )

    # class MPTTMeta:
    #     parent_attr = 'parent_comment'

    def __str__(self):
        return self.comment
