from rest_framework import serializers
from core.serializers import ModelSerializer
from projects.serializers import ProjectSerializer
from users.serializers import UserSerializer
from .models import Question, QuestionComment
from rest_framework_recursive.fields import RecursiveField

class QuestionSerializer(ModelSerializer):
    date = serializers.ReadOnlyField()

    class Meta:
        model = Question
        fields = (
            'id',
            'date',
            'user',
            'project',
            'text',
        )
        relation_fields = [
            ('project', ProjectSerializer),
            ('user', UserSerializer),
        ]

class CommentSerializer(ModelSerializer):
    date = serializers.ReadOnlyField()

    class Meta:
        model = QuestionComment
        fields = (
            'id',
            'date',
            'user',
            'comment',
            'question',
            # 'parent_comment',
            # 'children',
            'answer',
        )
        relation_fields = [
            ('user', UserSerializer),
            ('question', QuestionSerializer),
        ]

class QuestionCommentSerializer(ModelSerializer):
    date = serializers.ReadOnlyField()
    children = serializers.ListSerializer(child=RecursiveField(),
                                           required=False, )
    # rel_parent_comment = serializers.PrimaryKeyRelatedField(
        # queryset=QuestionComment.objects.filter('parent_comment'))

    class Meta:
        model = QuestionComment
        fields = (
            'id',
            'date',
            'user',
            'comment',
            'question',
            'parent_comment',
            'children',
            'answer',
        )
        relation_fields = [
            ('user', UserSerializer),
            ('question', QuestionSerializer),
            ('parent_comment', CommentSerializer)
        ]


