from django.db import models
from django.core.validators import MaxValueValidator, MinValueValidator

class Risk(models.Model):
    project = models.ForeignKey(
        'projects.Project',
        on_delete=models.CASCADE,
        verbose_name='проект',
    )
    category = models.ForeignKey(
        'RiskCategory',
        on_delete=models.CASCADE,
        verbose_name='категория',
        related_name="risks",
        blank=True,
        null=True
    )
    risk = models.CharField(
        'Риск',
        max_length = 255,
        blank=True,
        null=True
    )
    # TODO: вероятность - это probability
    # Как теперь я могу это переименовать, в клиентской части не хочет перегенирироваться с новым именем
    probability = models.PositiveIntegerField(
        'Вероятность наступления(в %)',
        default=0,
        validators=[MinValueValidator(0), MaxValueValidator(100)],
    )

    effects = models.PositiveIntegerField(
        'Степень последствий',
        default=0,
        validators=[MinValueValidator(0), MaxValueValidator(10)],

    )
    control_method = models.TextField(
        'Способы управления',
        blank=True,
        null=True
    )
    order = models.PositiveIntegerField(
        'порядок',
        blank=False,
        null=False,
    )

    def __str__(self):
        if self.risk :
            return str(self.project) + ' - ' + str(self.risk)
        else:
            return str(self.project) + ' - ' + '...'

    class Meta:
        ordering = ['order', '-probability', '-effects']

class RiskCategory(models.Model):
    name = models.CharField(
        'имя категории',
        max_length=100,
        unique=True
    )
    order = models.IntegerField(
        'порядок',
        default=10
    )

    def __str__(self):
        return self.name

    class Meta:
        verbose_name_plural = 'Risks categories'
