from django.test import TestCase
from .models import Role, UserRole
from users.models import User
from projects.models import ProjectGroup, Project, ProjectType, ProjectCategory
from companies.models import Company
from django.core.exceptions import ValidationError


class RoleTestCase(TestCase):
    def setUp(self):
        pass
    
    def test_role_validation(self):
        self.assertRaises(ValidationError, Role.objects.create, name='Test role')
        role = Role.objects.create(name='Test role', company=True)
        role.company = False
        self.assertRaises(ValidationError, role.save)


class UserRoleTestCase(TestCase):
    role_name = 'Test role'
    custom_role_name = 'Custom test role'

    def setUp(self):
        self.role = Role.objects.create(name=self.role_name, company=True)
        self.user = User.objects.create(
            email='ivanov',
            first_name='Иван',
            middle_name='Валентинович',
            last_name='Иванов',
        )
        self.company = Company.objects.create(name='РогаИкопыта', full_name='ООО РиК')
        self.project_group = ProjectGroup.objects.create(
            name='Test project group',
            company=self.company,
        )

        self.project = Project.objects.create(
            name='Test project',
            abbr='TPR',
            project_type=ProjectType.objects.create(
                name='Test project type',
                category=ProjectCategory.objects.create(
                    name='Test project category',
                    eng_name='TPC',
                )
            ),
            project_group=ProjectGroup.objects.create(
                name='Test project group',
                company=self.company
            )
        )

    def test_get_name(self):
        user_role1 = UserRole.objects.create(
            user=self.user,
            role=self.role,
            custom_name=self.custom_role_name,
        )
        user_role2 = UserRole.objects.create(
            user=self.user,
            role=self.role,
        )

        self.assertEqual(user_role1.get_role_name(), self.custom_role_name)
        self.assertEqual(user_role2.get_role_name(), self.role_name)

    def test_get_permission_object(self):
        user_role_pr = UserRole.objects.create(
            user=self.user,
            role=self.role,
            project=self.project,
        )
        user_role_prgr = UserRole.objects.create(
            user=self.user,
            role=self.role,
            project_group=self.project_group,
        )
        user_role_comp = UserRole.objects.create(
            user=self.user,
            role=self.role,
            company=self.company
        )
        user_role_glob = UserRole.objects.create(
            user=self.user,
            role=self.role,
        )
        self.assertEqual(user_role_comp.get_permission_object(), self.company)
        self.assertEqual(user_role_pr.get_permission_object(), self.project)
        self.assertEqual(user_role_prgr.get_permission_object(), self.project_group)
        self.assertEqual(user_role_glob.get_permission_object(), None)
