from django.db import models
from django.core.validators import MaxValueValidator, MinValueValidator


class Stakeholder(models.Model):
    project = models.ForeignKey(
        'projects.Project',
        on_delete=models.CASCADE,
        verbose_name='проект',
    )
    stakeholder = models.ForeignKey(
        'companies.Company',
        on_delete=models.CASCADE,
        verbose_name='заинтересованная сторона',
        blank=True,
        null=True
    )
    interest = models.PositiveIntegerField(
        'Степень заинтересованности',
        default=0,
        validators=[MinValueValidator(0), MaxValueValidator(10)],
        blank=True,
        null=True
    )
    impact = models.PositiveIntegerField(
        'Влияние на проект',
        default=0,
        validators=[MinValueValidator(0), MaxValueValidator(10)],
        blank=True,
        null=True
    )
    order = models.PositiveIntegerField(
        'порядок',
        blank=False,
        null=False,
    )

    def __str__(self):
        if self.stakeholder:
            return str(self.project.name) + ' - ' + str(self.stakeholder.name)
        else:
            return str(self.project.name)

    class Meta:
        ordering = ['order', '-impact', '-interest']