from rest_framework import serializers
from .models import User, UserLastProjectView
from djoser import serializers as djoser_serializers
from companies.serializers import CompanySerializer, DepartmentSerializer
from core.serializers import ModelSerializer
from contacts.serializers import VacationSerializer, TelephoneSerializer


class DeputySerializer(ModelSerializer):
    class Meta:
        model = User
        fields = (
            'id',
            'email',
            'first_name',
            'middle_name',
            'last_name',
            'birthday',
            'place',
            'deputy',
            'avatar',
            'company',
            'department',
            'department_manager',
            'position',
            'full_name',
            'short_name',
            'telephones',
            'vacations'
        )
        relation_fields = [('company', CompanySerializer),
                           ('telephones', TelephoneSerializer),
                           ('vacations', VacationSerializer),
                           ('department', DepartmentSerializer)]


class UserBaseSerializer(ModelSerializer):
    telephones = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    vacations = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    deputy = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=False)

    class Meta:
        model = User
        fields = (
            'id',
            'email',
            'first_name',
            'middle_name',
            'last_name',
            'birthday',
            'place',
            'deputy',
            'avatar',
            'company',
            'department',
            'department_manager',
            'position',
            'full_name',
            'short_name',
            'telephones',
            'vacations',
        )


class UserSerializer(UserBaseSerializer):

    class Meta:
        model = User
        fields = UserBaseSerializer.Meta.fields
        relation_fields = [('company', CompanySerializer),
                           ('telephones', TelephoneSerializer),
                           ('vacations', VacationSerializer),
                           ('department', DepartmentSerializer),
                           ('deputy', DeputySerializer)]


class UserLastProjectViewSerializer(ModelSerializer):

    class Meta:
        model = UserLastProjectView
        fields = '__all__'
        relation_fields = [
            ('user', UserSerializer)
        ]


class UserAvatarSerializer(ModelSerializer):
    class Meta:
        model = User
        fields = ["avatar"]

    def save(self, *args, **kwargs):
        if self.instance.avatar:
            self.instance.avatar = None
        return super().save(*args, **kwargs)


class UserCreateSerializer(djoser_serializers.UserCreateSerializer):
    # middle_name = serializers.CharField(max_length=255)

    class Meta:
        model = User
        fields = djoser_serializers.UserCreateSerializer.Meta.fields + ('middle_name', )
