from rest_framework import serializers
from news.serializers import NewsEntrySerializer
from core.mixins import RelationFieldsSerializerMixin
from projects.serializers import ProjectSerializer, ProjectGroupSerializer


class UserNewsSerializer(RelationFieldsSerializerMixin, serializers.Serializer):
    newsEntry = NewsEntrySerializer(
        many=True,
        read_only=True,
        include=['user', 'project', 'company', 'departament']
    )


class UserPermissionsSerializer(serializers.Serializer):
    permissions = serializers.ListField(read_only=True)


class UserProjectsSerializer(RelationFieldsSerializerMixin, serializers.Serializer):
    projects = ProjectSerializer(
        many=True,
        read_only=True,
        include=['stages', 'preferences', 'customer',
                 'users_roles__role',
                 'general_customer', 'project_group', 'project_type',
                 'project_meta_values']
    )


class UserProjectGroupsSerializer(RelationFieldsSerializerMixin, serializers.Serializer):
    project_groups = ProjectGroupSerializer(
        many=True,
        read_only=True,
        include=['projects', 'subgroups']
    )


class UserAllProjectsSerializer(RelationFieldsSerializerMixin, serializers.Serializer):
    project_groups = ProjectGroupSerializer(
        many=True,
        read_only=True,
        include=['parent_group',
                 'projects',
                 'projects__stages',
                 'projects__preferences',
                 'projects__customer',
                 'projects__general_customer'
                 'projects__project_type',
                 'projects__project_meta_values'
                 ]
    )
    projects = ProjectSerializer(
        many=True,
        read_only=True,
        include=['stages',
                 'preferences',
                 'customer',
                 'general_customer',
                 'users_roles__role',
                 'project_group',
                 'project_type',
                 'project_group__parent_group',
                 'project_meta_values']
    )
    projects_user_watcher = ProjectSerializer(
        many=True,
        read_only=True,
        include=['stages',
                 'preferences',
                 'customer',
                 'general_customer',
                 'project_group',
                 'project_type',
                 'watchers',
                 'project_meta_values'],
    )
