from core.serializers import ModelSerializer
from projects.serializers import ProjectSerializer
from users.serializers import UserSerializer
from rest_framework import serializers
from .models import Work, WorkLink


class WorkIndicatorSerializer(serializers.Serializer):
    general = serializers.ChoiceField(read_only=True, choices=Work.IndicatorChoices.choices)
    start = serializers.ChoiceField(read_only=True, choices=Work.IndicatorChoices.choices)
    finish = serializers.ChoiceField(read_only=True, choices=Work.IndicatorChoices.choices)


class WorkSerializer(ModelSerializer):
    works = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)
    subworks = serializers.PrimaryKeyRelatedField(read_only=True, required=False, many=True)

    class Meta:
        model = Work
        fields = '__all__'
        relation_fields = [
            ('to_user', UserSerializer),
            ('val_user', UserSerializer),
            ('created_by', UserSerializer),
            ('done_by', UserSerializer),
            ('val_by', UserSerializer),
            ('project', ProjectSerializer),
        ]


class WorkLinkSerializer(ModelSerializer):
    class Meta:
        model = WorkLink
        fields = '__all__'


class WorkStatusSerializer(ModelSerializer):
    class Meta:
        model = Work
        fields = ('status', )
